.. _virtualmachine module:

:mod:`oca.virtualmachine`
--------------------------------

.. autoclass:: oca.VirtualMachine
    :members:
.. autoclass:: oca.VirtualMachinePool
    :members: info
    :no-inherited-members:
